@@ -15,12 +15,70 @@ from .._jsii import *
 import ros_cdk_core as _ros_cdk_core_7adfd82f
 
 
+@jsii.interface(jsii_type="@alicloud/ros-cdk-appflow.datasource.IUserAuthConfigs")
+class IUserAuthConfigs(_ros_cdk_core_7adfd82f.IResource, typing_extensions.Protocol):
+    '''Represents a ``UserAuthConfigs``.'''
+
+    @builtins.property
+    @jsii.member(jsii_name="attrAuthConfigIds")
+    def attr_auth_config_ids(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute AuthConfigIds: The list of auth config ids.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrAuthConfigs")
+    def attr_auth_configs(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute AuthConfigs: The list of auth configs.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="props")
+    def props(self) -> "UserAuthConfigsProps":
+        ...
+
+
+class _IUserAuthConfigsProxy(
+    jsii.proxy_for(_ros_cdk_core_7adfd82f.IResource), # type: ignore[misc]
+):
+    '''Represents a ``UserAuthConfigs``.'''
+
+    __jsii_type__: typing.ClassVar[str] = "@alicloud/ros-cdk-appflow.datasource.IUserAuthConfigs"
+
+    @builtins.property
+    @jsii.member(jsii_name="attrAuthConfigIds")
+    def attr_auth_config_ids(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute AuthConfigIds: The list of auth config ids.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrAuthConfigIds"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrAuthConfigs")
+    def attr_auth_configs(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute AuthConfigs: The list of auth configs.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrAuthConfigs"))
+
+    @builtins.property
+    @jsii.member(jsii_name="props")
+    def props(self) -> "UserAuthConfigsProps":
+        return typing.cast("UserAuthConfigsProps", jsii.get(self, "props"))
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IUserAuthConfigs).__jsii_proxy_class__ = lambda : _IUserAuthConfigsProxy
+
+
 class RosUserAuthConfigs(
     _ros_cdk_core_7adfd82f.RosResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-appflow.datasource.RosUserAuthConfigs",
 ):
-    '''This class is a base encapsulation around the ROS resource type ``DATASOURCE::AppFlow::UserAuthConfigs``.
+    '''This class is a base encapsulation around the ROS resource type ``DATASOURCE::AppFlow::UserAuthConfigs``, which is used to query the configurations of user credentials.
 
     :Note:
 
@@ -255,12 +313,13 @@ class RosUserAuthConfigsProps:
         )
 
 
+@jsii.implements(IUserAuthConfigs)
 class UserAuthConfigs(
     _ros_cdk_core_7adfd82f.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-appflow.datasource.UserAuthConfigs",
 ):
-    '''This class encapsulates and extends the ROS resource type ``DATASOURCE::AppFlow::UserAuthConfigs``.
+    '''This class encapsulates and extends the ROS resource type ``DATASOURCE::AppFlow::UserAuthConfigs``, which is used to query the configurations of user credentials.
 
     :Note:
 
@@ -292,15 +351,24 @@ class UserAuthConfigs(
 
     @builtins.property
     @jsii.member(jsii_name="attrAuthConfigIds")
-    def attr_auth_config_ids(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_auth_config_ids(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute AuthConfigIds: The list of auth config ids.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrAuthConfigIds"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrAuthConfigIds"))
 
     @builtins.property
     @jsii.member(jsii_name="attrAuthConfigs")
-    def attr_auth_configs(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_auth_configs(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute AuthConfigs: The list of auth configs.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrAuthConfigs"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrAuthConfigs"))
+
+    @builtins.property
+    @jsii.member(jsii_name="props")
+    def props(self) -> "UserAuthConfigsProps":
+        return typing.cast("UserAuthConfigsProps", jsii.get(self, "props"))
 
     @builtins.property
     @jsii.member(jsii_name="enableResourcePropertyConstraint")
@@ -326,18 +394,6 @@ class UserAuthConfigs(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
-    @builtins.property
-    @jsii.member(jsii_name="props")
-    def _props(self) -> "UserAuthConfigsProps":
-        return typing.cast("UserAuthConfigsProps", jsii.get(self, "props"))
-
-    @_props.setter
-    def _props(self, value: "UserAuthConfigsProps") -> None:
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__59739e498b9e840370d0e40a0d632e12114fdfd80bcb91a91191399a3420e8ad)
-            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
-        jsii.set(self, "props", value)
-
     @builtins.property
     @jsii.member(jsii_name="scope")
     def _scope(self) -> _ros_cdk_core_7adfd82f.Construct:
@@ -434,6 +490,7 @@ class UserAuthConfigsProps:
 
 
 __all__ = [
+    "IUserAuthConfigs",
     "RosUserAuthConfigs",
     "RosUserAuthConfigsProps",
     "UserAuthConfigs",
@@ -511,12 +568,6 @@ def _typecheckingstub__15adc4d02ccfa07c78f34629d9930d84420c11d2bd4d3d8179412b2a8
     """Type checking stubs"""
     pass
 
-def _typecheckingstub__59739e498b9e840370d0e40a0d632e12114fdfd80bcb91a91191399a3420e8ad(
-    value: UserAuthConfigsProps,
-) -> None:
-    """Type checking stubs"""
-    pass
-
 def _typecheckingstub__12449963f454eb276f74b322cb5dc02572c87b22bc8d4107e1e41715a6abbbe8(
     value: _ros_cdk_core_7adfd82f.Construct,
 ) -> None:
